PhotolineHolderDragController class
Drag controller.
- Implemented types
Constructors
Properties
- closeDx ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- holder ↔ PhotolineHolderState?
-
=== Drag
getter/setter pair
- isDrag ↔ bool
-
getter/setter pair
- isDragClose ↔ bool
-
getter/setter pair
- removeDx ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void -
The input from the pointer is no longer directed towards this receiver.
override
-
end(
DragEndDetails details) → void -
The pointer is no longer in contact with the screen.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAnimationDrag(
) → void -
onPointerDown(
PhotolineController controller, PhotolineTileState tile, PointerDownEvent event) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
DragUpdateDetails details) → void -
The pointer has moved.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited